@@ -29,13 +29,18 @@
 class CommandHistory::Private
 {
 public:
-    Private() : m_manager(nullptr), m_undoStack() {}
-    KBookmarkManager* m_manager;
+    Private()
+        : m_manager(nullptr)
+        , m_undoStack()
+    {
+    }
+    KBookmarkManager *m_manager;
     QUndoStack m_undoStack;
 };
 
-CommandHistory::CommandHistory(QObject* parent)
-    : QObject(parent), d(new CommandHistory::Private)
+CommandHistory::CommandHistory(QObject *parent)
+    : QObject(parent)
+    , d(new CommandHistory::Private)
 {
 }
 
@@ -44,7 +49,7 @@ CommandHistory::~CommandHistory()
     delete d;
 }
 
-void CommandHistory::setBookmarkManager(KBookmarkManager* manager)
+void CommandHistory::setBookmarkManager(KBookmarkManager *manager)
 {
     clearHistory(); // we can't keep old commands pointing to the wrong model/manager...
     d->m_manager = manager;
@@ -59,7 +64,7 @@ void CommandHistory::createActions(KActionCollection *actionCollection)
     undoAction->setIcon(standardAction->icon());
     actionCollection->addAction(KStandardAction::name(KStandardAction::Undo), undoAction);
     actionCollection->setDefaultShortcuts(undoAction, standardAction->shortcuts());
-    disconnect(undoAction, SIGNAL(triggered()), &d->m_undoStack, nullptr);
+    disconnect(undoAction, &QAction::triggered, &d->m_undoStack, nullptr);
     connect(undoAction, &QAction::triggered, this, &CommandHistory::undo);
     delete standardAction;
 
@@ -68,7 +73,7 @@ void CommandHistory::createActions(KActionCollection *actionCollection)
     redoAction->setIcon(standardAction->icon());
     actionCollection->addAction(KStandardAction::name(KStandardAction::Redo), redoAction);
     actionCollection->setDefaultShortcuts(redoAction, standardAction->shortcuts());
-    disconnect(redoAction, SIGNAL(triggered()), &d->m_undoStack, nullptr);
+    disconnect(redoAction, &QAction::triggered, &d->m_undoStack, nullptr);
     connect(redoAction, &QAction::triggered, this, &CommandHistory::redo);
     delete standardAction;
 }
@@ -76,7 +81,7 @@ void CommandHistory::createActions(KActionCollection *actionCollection)
 void CommandHistory::undo()
 {
     const int idx = d->m_undoStack.index();
-    const QUndoCommand* cmd = d->m_undoStack.command(idx-1);
+    const QUndoCommand *cmd = d->m_undoStack.command(idx - 1);
     if (cmd) {
         d->m_undoStack.undo();
         commandExecuted(cmd);
@@ -86,7 +91,7 @@ void CommandHistory::undo()
 void CommandHistory::redo()
 {
     const int idx = d->m_undoStack.index();
-    const QUndoCommand* cmd = d->m_undoStack.command(idx);
+    const QUndoCommand *cmd = d->m_undoStack.command(idx);
     if (cmd) {
         d->m_undoStack.redo();
         commandExecuted(cmd);
@@ -95,13 +100,13 @@ void CommandHistory::redo()
 
 void CommandHistory::commandExecuted(const QUndoCommand *k)
 {
-    const IKEBCommand * cmd = dynamic_cast<const IKEBCommand *>(k);
+    const IKEBCommand *cmd = dynamic_cast<const IKEBCommand *>(k);
     Q_ASSERT(cmd);
 
     KBookmark bk = d->m_manager->findByAddress(cmd->affectedBookmarks());
     Q_ASSERT(bk.isGroup());
 
-    emit notifyCommandExecuted(bk.toGroup());
+    Q_EMIT notifyCommandExecuted(bk.toGroup());
 }
 
 void CommandHistory::notifyDocSaved()
@@ -121,13 +126,11 @@ void CommandHistory::clearHistory()
 {
     if (d->m_undoStack.count() > 0) {
         d->m_undoStack.clear();
-        emit notifyCommandExecuted(d->m_manager->root()); // not really, but we still want to update the GUI
+        Q_EMIT notifyCommandExecuted(d->m_manager->root()); // not really, but we still want to update the GUI
     }
 }
 
-KBookmarkManager* CommandHistory::bookmarkManager()
+KBookmarkManager *CommandHistory::bookmarkManager()
 {
     return d->m_manager;
 }
-
-
